@@ -1,8 +1,8 @@
 import numpy as np
 import pandas as pd
 import networkx as nx
+from teaspoon.SP.tsa_tools import takens
 from teaspoon.parameter_selection import MI_delay, MsPE, FNN_n
-from teaspoon.SP import tsa_tools
 from teaspoon.SP.tsa_tools import permutation_sequence, cgss_sequence
 import os
 import sys
@@ -94,7 +94,7 @@ def knn_graph(ts, n=None, tau=None, k=4):
     if n == None:
         perc_FNN, n = FNN_n.FNN_n(ts, tau)
 
-    ETS = tsa_tools.takens(ts, n, tau)  # get embedded time series
+    ETS = takens(ts, n, tau)  # get embedded time series
 
     distances, indices = tsa_tools.k_NN(ETS, k=k)
     # gets distances between embedded vectors and the indices of the nearest neighbors for every vector
@@ -147,6 +147,7 @@ def cgss_graph(ts, B_array, n=None, tau=None):
     Returns:
         [2-D square array]: A (2-D weighted and directed square adjacency matrix)
     """
+
     if tau == None:
         tau = MI_delay.MI_for_delay(
             ts, method='basic', h_method='sturge', k=2, ranking=True)
